"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[5394,827],{65394:(e,t,r)=>{r.r(t),r.d(t,{default:()=>s});var i=r(79615),l=r(38170),a=r(60699);const n="@jupyterlite/pyolite-kernel-extension:kernel",s=[{id:n,autoStart:!0,requires:[a.IKernelSpecs,l.IServiceWorkerRegistrationWrapper],activate:(e,t,l)=>{const a=i.PageConfig.getBaseUrl(),s=JSON.parse(i.PageConfig.getOption("litePluginSettings")||"{}")[n]||{},o=s.pyodideUrl||"https://cdn.jsdelivr.net/pyodide/v0.21.3/full/pyodide.js",p=i.URLExt.parse(o).href,d=(s.pipliteUrls||[]).map((e=>i.URLExt.parse(e).href)),c=!!s.disablePyPIFallback;t.register({spec:{name:"python",display_name:"Python (Pyodide)",language:"python",argv:[],resources:{"logo-32x32":"TODO","logo-64x64":i.URLExt.join(a,"/kernelspecs/python.svg")}},create:async e=>{const{PyoliteKernel:t}=await Promise.all([r.e(6169),r.e(1008)]).then(r.bind(r,40390));return new t({...e,pyodideUrl:p,pipliteUrls:d,disablePyPIFallback:c,mountDrive:l.enabled})}})}}]}}]);
//# sourceMappingURL=5394.d9ffb63.js.map