"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[9866],{89866:(t,a,e)=>{e.r(a),e.d(a,{default:()=>T});var o=e(57324),r=e(38109),s=e(89180);const T={id:"@jupyterlab/celltags",autoStart:!0,requires:[o.INotebookTools,o.INotebookTracker,s.ITranslator],activate:(t,a,e,o)=>{const s=new r.TagTool(e,t,o);a.addItem({tool:s,rank:1.6})}}}}]);
//# sourceMappingURL=9866.fd87dbe.js.map